use 5.006;
use strict;
use warnings;

# this test was generated with Dist::Zilla::Plugin::Test::Compile 2.058

use Test::More;

plan tests => 373;

my @module_files = (
    'DateTime/TimeZone.pm',
    'DateTime/TimeZone/Africa/Abidjan.pm',
    'DateTime/TimeZone/Africa/Accra.pm',
    'DateTime/TimeZone/Africa/Algiers.pm',
    'DateTime/TimeZone/Africa/Bissau.pm',
    'DateTime/TimeZone/Africa/Cairo.pm',
    'DateTime/TimeZone/Africa/Casablanca.pm',
    'DateTime/TimeZone/Africa/Ceuta.pm',
    'DateTime/TimeZone/Africa/El_Aaiun.pm',
    'DateTime/TimeZone/Africa/Johannesburg.pm',
    'DateTime/TimeZone/Africa/Juba.pm',
    'DateTime/TimeZone/Africa/Khartoum.pm',
    'DateTime/TimeZone/Africa/Lagos.pm',
    'DateTime/TimeZone/Africa/Maputo.pm',
    'DateTime/TimeZone/Africa/Monrovia.pm',
    'DateTime/TimeZone/Africa/Nairobi.pm',
    'DateTime/TimeZone/Africa/Ndjamena.pm',
    'DateTime/TimeZone/Africa/Sao_Tome.pm',
    'DateTime/TimeZone/Africa/Tripoli.pm',
    'DateTime/TimeZone/Africa/Tunis.pm',
    'DateTime/TimeZone/Africa/Windhoek.pm',
    'DateTime/TimeZone/America/Adak.pm',
    'DateTime/TimeZone/America/Anchorage.pm',
    'DateTime/TimeZone/America/Araguaina.pm',
    'DateTime/TimeZone/America/Argentina/Buenos_Aires.pm',
    'DateTime/TimeZone/America/Argentina/Catamarca.pm',
    'DateTime/TimeZone/America/Argentina/Cordoba.pm',
    'DateTime/TimeZone/America/Argentina/Jujuy.pm',
    'DateTime/TimeZone/America/Argentina/La_Rioja.pm',
    'DateTime/TimeZone/America/Argentina/Mendoza.pm',
    'DateTime/TimeZone/America/Argentina/Rio_Gallegos.pm',
    'DateTime/TimeZone/America/Argentina/Salta.pm',
    'DateTime/TimeZone/America/Argentina/San_Juan.pm',
    'DateTime/TimeZone/America/Argentina/San_Luis.pm',
    'DateTime/TimeZone/America/Argentina/Tucuman.pm',
    'DateTime/TimeZone/America/Argentina/Ushuaia.pm',
    'DateTime/TimeZone/America/Asuncion.pm',
    'DateTime/TimeZone/America/Atikokan.pm',
    'DateTime/TimeZone/America/Bahia.pm',
    'DateTime/TimeZone/America/Bahia_Banderas.pm',
    'DateTime/TimeZone/America/Barbados.pm',
    'DateTime/TimeZone/America/Belem.pm',
    'DateTime/TimeZone/America/Belize.pm',
    'DateTime/TimeZone/America/Blanc_Sablon.pm',
    'DateTime/TimeZone/America/Boa_Vista.pm',
    'DateTime/TimeZone/America/Bogota.pm',
    'DateTime/TimeZone/America/Boise.pm',
    'DateTime/TimeZone/America/Cambridge_Bay.pm',
    'DateTime/TimeZone/America/Campo_Grande.pm',
    'DateTime/TimeZone/America/Cancun.pm',
    'DateTime/TimeZone/America/Caracas.pm',
    'DateTime/TimeZone/America/Cayenne.pm',
    'DateTime/TimeZone/America/Chicago.pm',
    'DateTime/TimeZone/America/Chihuahua.pm',
    'DateTime/TimeZone/America/Costa_Rica.pm',
    'DateTime/TimeZone/America/Creston.pm',
    'DateTime/TimeZone/America/Cuiaba.pm',
    'DateTime/TimeZone/America/Curacao.pm',
    'DateTime/TimeZone/America/Danmarkshavn.pm',
    'DateTime/TimeZone/America/Dawson.pm',
    'DateTime/TimeZone/America/Dawson_Creek.pm',
    'DateTime/TimeZone/America/Denver.pm',
    'DateTime/TimeZone/America/Detroit.pm',
    'DateTime/TimeZone/America/Edmonton.pm',
    'DateTime/TimeZone/America/Eirunepe.pm',
    'DateTime/TimeZone/America/El_Salvador.pm',
    'DateTime/TimeZone/America/Fort_Nelson.pm',
    'DateTime/TimeZone/America/Fortaleza.pm',
    'DateTime/TimeZone/America/Glace_Bay.pm',
    'DateTime/TimeZone/America/Godthab.pm',
    'DateTime/TimeZone/America/Goose_Bay.pm',
    'DateTime/TimeZone/America/Grand_Turk.pm',
    'DateTime/TimeZone/America/Guatemala.pm',
    'DateTime/TimeZone/America/Guayaquil.pm',
    'DateTime/TimeZone/America/Guyana.pm',
    'DateTime/TimeZone/America/Halifax.pm',
    'DateTime/TimeZone/America/Havana.pm',
    'DateTime/TimeZone/America/Hermosillo.pm',
    'DateTime/TimeZone/America/Indiana/Indianapolis.pm',
    'DateTime/TimeZone/America/Indiana/Knox.pm',
    'DateTime/TimeZone/America/Indiana/Marengo.pm',
    'DateTime/TimeZone/America/Indiana/Petersburg.pm',
    'DateTime/TimeZone/America/Indiana/Tell_City.pm',
    'DateTime/TimeZone/America/Indiana/Vevay.pm',
    'DateTime/TimeZone/America/Indiana/Vincennes.pm',
    'DateTime/TimeZone/America/Indiana/Winamac.pm',
    'DateTime/TimeZone/America/Inuvik.pm',
    'DateTime/TimeZone/America/Iqaluit.pm',
    'DateTime/TimeZone/America/Jamaica.pm',
    'DateTime/TimeZone/America/Juneau.pm',
    'DateTime/TimeZone/America/Kentucky/Louisville.pm',
    'DateTime/TimeZone/America/Kentucky/Monticello.pm',
    'DateTime/TimeZone/America/La_Paz.pm',
    'DateTime/TimeZone/America/Lima.pm',
    'DateTime/TimeZone/America/Los_Angeles.pm',
    'DateTime/TimeZone/America/Maceio.pm',
    'DateTime/TimeZone/America/Managua.pm',
    'DateTime/TimeZone/America/Manaus.pm',
    'DateTime/TimeZone/America/Martinique.pm',
    'DateTime/TimeZone/America/Matamoros.pm',
    'DateTime/TimeZone/America/Mazatlan.pm',
    'DateTime/TimeZone/America/Menominee.pm',
    'DateTime/TimeZone/America/Merida.pm',
    'DateTime/TimeZone/America/Metlakatla.pm',
    'DateTime/TimeZone/America/Mexico_City.pm',
    'DateTime/TimeZone/America/Miquelon.pm',
    'DateTime/TimeZone/America/Moncton.pm',
    'DateTime/TimeZone/America/Monterrey.pm',
    'DateTime/TimeZone/America/Montevideo.pm',
    'DateTime/TimeZone/America/Nassau.pm',
    'DateTime/TimeZone/America/New_York.pm',
    'DateTime/TimeZone/America/Nipigon.pm',
    'DateTime/TimeZone/America/Nome.pm',
    'DateTime/TimeZone/America/Noronha.pm',
    'DateTime/TimeZone/America/North_Dakota/Beulah.pm',
    'DateTime/TimeZone/America/North_Dakota/Center.pm',
    'DateTime/TimeZone/America/North_Dakota/New_Salem.pm',
    'DateTime/TimeZone/America/Ojinaga.pm',
    'DateTime/TimeZone/America/Panama.pm',
    'DateTime/TimeZone/America/Pangnirtung.pm',
    'DateTime/TimeZone/America/Paramaribo.pm',
    'DateTime/TimeZone/America/Phoenix.pm',
    'DateTime/TimeZone/America/Port_au_Prince.pm',
    'DateTime/TimeZone/America/Port_of_Spain.pm',
    'DateTime/TimeZone/America/Porto_Velho.pm',
    'DateTime/TimeZone/America/Puerto_Rico.pm',
    'DateTime/TimeZone/America/Punta_Arenas.pm',
    'DateTime/TimeZone/America/Rainy_River.pm',
    'DateTime/TimeZone/America/Rankin_Inlet.pm',
    'DateTime/TimeZone/America/Recife.pm',
    'DateTime/TimeZone/America/Regina.pm',
    'DateTime/TimeZone/America/Resolute.pm',
    'DateTime/TimeZone/America/Rio_Branco.pm',
    'DateTime/TimeZone/America/Santarem.pm',
    'DateTime/TimeZone/America/Santiago.pm',
    'DateTime/TimeZone/America/Santo_Domingo.pm',
    'DateTime/TimeZone/America/Sao_Paulo.pm',
    'DateTime/TimeZone/America/Scoresbysund.pm',
    'DateTime/TimeZone/America/Sitka.pm',
    'DateTime/TimeZone/America/St_Johns.pm',
    'DateTime/TimeZone/America/Swift_Current.pm',
    'DateTime/TimeZone/America/Tegucigalpa.pm',
    'DateTime/TimeZone/America/Thule.pm',
    'DateTime/TimeZone/America/Thunder_Bay.pm',
    'DateTime/TimeZone/America/Tijuana.pm',
    'DateTime/TimeZone/America/Toronto.pm',
    'DateTime/TimeZone/America/Vancouver.pm',
    'DateTime/TimeZone/America/Whitehorse.pm',
    'DateTime/TimeZone/America/Winnipeg.pm',
    'DateTime/TimeZone/America/Yakutat.pm',
    'DateTime/TimeZone/America/Yellowknife.pm',
    'DateTime/TimeZone/Antarctica/Casey.pm',
    'DateTime/TimeZone/Antarctica/Davis.pm',
    'DateTime/TimeZone/Antarctica/DumontDUrville.pm',
    'DateTime/TimeZone/Antarctica/Macquarie.pm',
    'DateTime/TimeZone/Antarctica/Mawson.pm',
    'DateTime/TimeZone/Antarctica/Palmer.pm',
    'DateTime/TimeZone/Antarctica/Rothera.pm',
    'DateTime/TimeZone/Antarctica/Syowa.pm',
    'DateTime/TimeZone/Antarctica/Troll.pm',
    'DateTime/TimeZone/Antarctica/Vostok.pm',
    'DateTime/TimeZone/Asia/Almaty.pm',
    'DateTime/TimeZone/Asia/Amman.pm',
    'DateTime/TimeZone/Asia/Anadyr.pm',
    'DateTime/TimeZone/Asia/Aqtau.pm',
    'DateTime/TimeZone/Asia/Aqtobe.pm',
    'DateTime/TimeZone/Asia/Ashgabat.pm',
    'DateTime/TimeZone/Asia/Atyrau.pm',
    'DateTime/TimeZone/Asia/Baghdad.pm',
    'DateTime/TimeZone/Asia/Baku.pm',
    'DateTime/TimeZone/Asia/Bangkok.pm',
    'DateTime/TimeZone/Asia/Barnaul.pm',
    'DateTime/TimeZone/Asia/Beirut.pm',
    'DateTime/TimeZone/Asia/Bishkek.pm',
    'DateTime/TimeZone/Asia/Brunei.pm',
    'DateTime/TimeZone/Asia/Chita.pm',
    'DateTime/TimeZone/Asia/Choibalsan.pm',
    'DateTime/TimeZone/Asia/Colombo.pm',
    'DateTime/TimeZone/Asia/Damascus.pm',
    'DateTime/TimeZone/Asia/Dhaka.pm',
    'DateTime/TimeZone/Asia/Dili.pm',
    'DateTime/TimeZone/Asia/Dubai.pm',
    'DateTime/TimeZone/Asia/Dushanbe.pm',
    'DateTime/TimeZone/Asia/Famagusta.pm',
    'DateTime/TimeZone/Asia/Gaza.pm',
    'DateTime/TimeZone/Asia/Hebron.pm',
    'DateTime/TimeZone/Asia/Ho_Chi_Minh.pm',
    'DateTime/TimeZone/Asia/Hong_Kong.pm',
    'DateTime/TimeZone/Asia/Hovd.pm',
    'DateTime/TimeZone/Asia/Irkutsk.pm',
    'DateTime/TimeZone/Asia/Jakarta.pm',
    'DateTime/TimeZone/Asia/Jayapura.pm',
    'DateTime/TimeZone/Asia/Jerusalem.pm',
    'DateTime/TimeZone/Asia/Kabul.pm',
    'DateTime/TimeZone/Asia/Kamchatka.pm',
    'DateTime/TimeZone/Asia/Karachi.pm',
    'DateTime/TimeZone/Asia/Kathmandu.pm',
    'DateTime/TimeZone/Asia/Khandyga.pm',
    'DateTime/TimeZone/Asia/Kolkata.pm',
    'DateTime/TimeZone/Asia/Krasnoyarsk.pm',
    'DateTime/TimeZone/Asia/Kuala_Lumpur.pm',
    'DateTime/TimeZone/Asia/Kuching.pm',
    'DateTime/TimeZone/Asia/Macau.pm',
    'DateTime/TimeZone/Asia/Magadan.pm',
    'DateTime/TimeZone/Asia/Makassar.pm',
    'DateTime/TimeZone/Asia/Manila.pm',
    'DateTime/TimeZone/Asia/Nicosia.pm',
    'DateTime/TimeZone/Asia/Novokuznetsk.pm',
    'DateTime/TimeZone/Asia/Novosibirsk.pm',
    'DateTime/TimeZone/Asia/Omsk.pm',
    'DateTime/TimeZone/Asia/Oral.pm',
    'DateTime/TimeZone/Asia/Pontianak.pm',
    'DateTime/TimeZone/Asia/Pyongyang.pm',
    'DateTime/TimeZone/Asia/Qatar.pm',
    'DateTime/TimeZone/Asia/Qyzylorda.pm',
    'DateTime/TimeZone/Asia/Riyadh.pm',
    'DateTime/TimeZone/Asia/Sakhalin.pm',
    'DateTime/TimeZone/Asia/Samarkand.pm',
    'DateTime/TimeZone/Asia/Seoul.pm',
    'DateTime/TimeZone/Asia/Shanghai.pm',
    'DateTime/TimeZone/Asia/Singapore.pm',
    'DateTime/TimeZone/Asia/Srednekolymsk.pm',
    'DateTime/TimeZone/Asia/Taipei.pm',
    'DateTime/TimeZone/Asia/Tashkent.pm',
    'DateTime/TimeZone/Asia/Tbilisi.pm',
    'DateTime/TimeZone/Asia/Tehran.pm',
    'DateTime/TimeZone/Asia/Thimphu.pm',
    'DateTime/TimeZone/Asia/Tokyo.pm',
    'DateTime/TimeZone/Asia/Tomsk.pm',
    'DateTime/TimeZone/Asia/Ulaanbaatar.pm',
    'DateTime/TimeZone/Asia/Urumqi.pm',
    'DateTime/TimeZone/Asia/Ust_Nera.pm',
    'DateTime/TimeZone/Asia/Vladivostok.pm',
    'DateTime/TimeZone/Asia/Yakutsk.pm',
    'DateTime/TimeZone/Asia/Yangon.pm',
    'DateTime/TimeZone/Asia/Yekaterinburg.pm',
    'DateTime/TimeZone/Asia/Yerevan.pm',
    'DateTime/TimeZone/Atlantic/Azores.pm',
    'DateTime/TimeZone/Atlantic/Bermuda.pm',
    'DateTime/TimeZone/Atlantic/Canary.pm',
    'DateTime/TimeZone/Atlantic/Cape_Verde.pm',
    'DateTime/TimeZone/Atlantic/Faroe.pm',
    'DateTime/TimeZone/Atlantic/Madeira.pm',
    'DateTime/TimeZone/Atlantic/Reykjavik.pm',
    'DateTime/TimeZone/Atlantic/South_Georgia.pm',
    'DateTime/TimeZone/Atlantic/Stanley.pm',
    'DateTime/TimeZone/Australia/Adelaide.pm',
    'DateTime/TimeZone/Australia/Brisbane.pm',
    'DateTime/TimeZone/Australia/Broken_Hill.pm',
    'DateTime/TimeZone/Australia/Currie.pm',
    'DateTime/TimeZone/Australia/Darwin.pm',
    'DateTime/TimeZone/Australia/Eucla.pm',
    'DateTime/TimeZone/Australia/Hobart.pm',
    'DateTime/TimeZone/Australia/Lindeman.pm',
    'DateTime/TimeZone/Australia/Lord_Howe.pm',
    'DateTime/TimeZone/Australia/Melbourne.pm',
    'DateTime/TimeZone/Australia/Perth.pm',
    'DateTime/TimeZone/Australia/Sydney.pm',
    'DateTime/TimeZone/CET.pm',
    'DateTime/TimeZone/CST6CDT.pm',
    'DateTime/TimeZone/Catalog.pm',
    'DateTime/TimeZone/EET.pm',
    'DateTime/TimeZone/EST.pm',
    'DateTime/TimeZone/EST5EDT.pm',
    'DateTime/TimeZone/Europe/Amsterdam.pm',
    'DateTime/TimeZone/Europe/Andorra.pm',
    'DateTime/TimeZone/Europe/Astrakhan.pm',
    'DateTime/TimeZone/Europe/Athens.pm',
    'DateTime/TimeZone/Europe/Belgrade.pm',
    'DateTime/TimeZone/Europe/Berlin.pm',
    'DateTime/TimeZone/Europe/Brussels.pm',
    'DateTime/TimeZone/Europe/Bucharest.pm',
    'DateTime/TimeZone/Europe/Budapest.pm',
    'DateTime/TimeZone/Europe/Chisinau.pm',
    'DateTime/TimeZone/Europe/Copenhagen.pm',
    'DateTime/TimeZone/Europe/Dublin.pm',
    'DateTime/TimeZone/Europe/Gibraltar.pm',
    'DateTime/TimeZone/Europe/Helsinki.pm',
    'DateTime/TimeZone/Europe/Istanbul.pm',
    'DateTime/TimeZone/Europe/Kaliningrad.pm',
    'DateTime/TimeZone/Europe/Kiev.pm',
    'DateTime/TimeZone/Europe/Kirov.pm',
    'DateTime/TimeZone/Europe/Lisbon.pm',
    'DateTime/TimeZone/Europe/London.pm',
    'DateTime/TimeZone/Europe/Luxembourg.pm',
    'DateTime/TimeZone/Europe/Madrid.pm',
    'DateTime/TimeZone/Europe/Malta.pm',
    'DateTime/TimeZone/Europe/Minsk.pm',
    'DateTime/TimeZone/Europe/Monaco.pm',
    'DateTime/TimeZone/Europe/Moscow.pm',
    'DateTime/TimeZone/Europe/Oslo.pm',
    'DateTime/TimeZone/Europe/Paris.pm',
    'DateTime/TimeZone/Europe/Prague.pm',
    'DateTime/TimeZone/Europe/Riga.pm',
    'DateTime/TimeZone/Europe/Rome.pm',
    'DateTime/TimeZone/Europe/Samara.pm',
    'DateTime/TimeZone/Europe/Saratov.pm',
    'DateTime/TimeZone/Europe/Simferopol.pm',
    'DateTime/TimeZone/Europe/Sofia.pm',
    'DateTime/TimeZone/Europe/Stockholm.pm',
    'DateTime/TimeZone/Europe/Tallinn.pm',
    'DateTime/TimeZone/Europe/Tirane.pm',
    'DateTime/TimeZone/Europe/Ulyanovsk.pm',
    'DateTime/TimeZone/Europe/Uzhgorod.pm',
    'DateTime/TimeZone/Europe/Vienna.pm',
    'DateTime/TimeZone/Europe/Vilnius.pm',
    'DateTime/TimeZone/Europe/Volgograd.pm',
    'DateTime/TimeZone/Europe/Warsaw.pm',
    'DateTime/TimeZone/Europe/Zaporozhye.pm',
    'DateTime/TimeZone/Europe/Zurich.pm',
    'DateTime/TimeZone/Floating.pm',
    'DateTime/TimeZone/HST.pm',
    'DateTime/TimeZone/Indian/Chagos.pm',
    'DateTime/TimeZone/Indian/Christmas.pm',
    'DateTime/TimeZone/Indian/Cocos.pm',
    'DateTime/TimeZone/Indian/Kerguelen.pm',
    'DateTime/TimeZone/Indian/Mahe.pm',
    'DateTime/TimeZone/Indian/Maldives.pm',
    'DateTime/TimeZone/Indian/Mauritius.pm',
    'DateTime/TimeZone/Indian/Reunion.pm',
    'DateTime/TimeZone/Local.pm',
    'DateTime/TimeZone/Local/Android.pm',
    'DateTime/TimeZone/Local/Unix.pm',
    'DateTime/TimeZone/Local/VMS.pm',
    'DateTime/TimeZone/MET.pm',
    'DateTime/TimeZone/MST.pm',
    'DateTime/TimeZone/MST7MDT.pm',
    'DateTime/TimeZone/OffsetOnly.pm',
    'DateTime/TimeZone/OlsonDB.pm',
    'DateTime/TimeZone/OlsonDB/Change.pm',
    'DateTime/TimeZone/OlsonDB/Observance.pm',
    'DateTime/TimeZone/OlsonDB/Rule.pm',
    'DateTime/TimeZone/OlsonDB/Zone.pm',
    'DateTime/TimeZone/PST8PDT.pm',
    'DateTime/TimeZone/Pacific/Apia.pm',
    'DateTime/TimeZone/Pacific/Auckland.pm',
    'DateTime/TimeZone/Pacific/Bougainville.pm',
    'DateTime/TimeZone/Pacific/Chatham.pm',
    'DateTime/TimeZone/Pacific/Chuuk.pm',
    'DateTime/TimeZone/Pacific/Easter.pm',
    'DateTime/TimeZone/Pacific/Efate.pm',
    'DateTime/TimeZone/Pacific/Enderbury.pm',
    'DateTime/TimeZone/Pacific/Fakaofo.pm',
    'DateTime/TimeZone/Pacific/Fiji.pm',
    'DateTime/TimeZone/Pacific/Funafuti.pm',
    'DateTime/TimeZone/Pacific/Galapagos.pm',
    'DateTime/TimeZone/Pacific/Gambier.pm',
    'DateTime/TimeZone/Pacific/Guadalcanal.pm',
    'DateTime/TimeZone/Pacific/Guam.pm',
    'DateTime/TimeZone/Pacific/Honolulu.pm',
    'DateTime/TimeZone/Pacific/Kiritimati.pm',
    'DateTime/TimeZone/Pacific/Kosrae.pm',
    'DateTime/TimeZone/Pacific/Kwajalein.pm',
    'DateTime/TimeZone/Pacific/Majuro.pm',
    'DateTime/TimeZone/Pacific/Marquesas.pm',
    'DateTime/TimeZone/Pacific/Nauru.pm',
    'DateTime/TimeZone/Pacific/Niue.pm',
    'DateTime/TimeZone/Pacific/Norfolk.pm',
    'DateTime/TimeZone/Pacific/Noumea.pm',
    'DateTime/TimeZone/Pacific/Pago_Pago.pm',
    'DateTime/TimeZone/Pacific/Palau.pm',
    'DateTime/TimeZone/Pacific/Pitcairn.pm',
    'DateTime/TimeZone/Pacific/Pohnpei.pm',
    'DateTime/TimeZone/Pacific/Port_Moresby.pm',
    'DateTime/TimeZone/Pacific/Rarotonga.pm',
    'DateTime/TimeZone/Pacific/Tahiti.pm',
    'DateTime/TimeZone/Pacific/Tarawa.pm',
    'DateTime/TimeZone/Pacific/Tongatapu.pm',
    'DateTime/TimeZone/Pacific/Wake.pm',
    'DateTime/TimeZone/Pacific/Wallis.pm',
    'DateTime/TimeZone/UTC.pm',
    'DateTime/TimeZone/WET.pm'
);



# no fake home requested

my @switches = (
    -d 'blib' ? '-Mblib' : '-Ilib',
);

use File::Spec;
use IPC::Open3;
use IO::Handle;

open my $stdin, '<', File::Spec->devnull or die "can't open devnull: $!";

my @warnings;
for my $lib (@module_files)
{
    # see L<perlfaq8/How can I capture STDERR from an external command?>
    my $stderr = IO::Handle->new;

    diag('Running: ', join(', ', map { my $str = $_; $str =~ s/'/\\'/g; q{'} . $str . q{'} }
            $^X, @switches, '-e', "require q[$lib]"))
        if $ENV{PERL_COMPILE_TEST_DEBUG};

    my $pid = open3($stdin, '>&STDERR', $stderr, $^X, @switches, '-e', "require q[$lib]");
    binmode $stderr, ':crlf' if $^O eq 'MSWin32';
    my @_warnings = <$stderr>;
    waitpid($pid, 0);
    is($?, 0, "$lib loaded ok");

    shift @_warnings if @_warnings and $_warnings[0] =~ /^Using .*\bblib/
        and not eval { +require blib; blib->VERSION('1.01') };

    if (@_warnings)
    {
        warn @_warnings;
        push @warnings, @_warnings;
    }
}



is(scalar(@warnings), 0, 'no warnings found')
    or diag 'got warnings: ', ( Test::More->can('explain') ? Test::More::explain(\@warnings) : join("\n", '', @warnings) );


